#ifndef _IO_H
#define _IO_H



/*===========================================================================

I/O connections:
----------------

RA0  <----  PWR_FWD     Forward power input (AN0)
RA1  <----  PWR_RWV     Reverse power input (AN1)
RA3  <----  RESERVED    Reserved, burt must be an analog input (AN3)

RB0  <----  SW_UNITS    Units swith (0=dB)
RB4  <----  DP_0        Decimal point bit 0
RB5  <----  DP_1        Decimal point bit 1
RB6  <----  SCALE_0     Scale bit 0
RB7  <----  SCALE_1     scale bit 1

RC0  ---->  LCD_D4      LCD display data bit 4
RC1  ---->  LCD_D5      LCD display data bit 5
RC2  ---->  LCD_D6      LCD display data bit 6
RC3  ---->  LCD_D7      LCD display data bit 7
RC4  ---->  LCD_RS      LCD display register select line (0=command, 1=data)
RC5  ---->  LCD_EN      LCD display enable line (1=enable)
RC6  ---->  LCD_LIGHT   LCD backlight enable line (1=on)

============================================================================= */



// --------------------------------------------------------------------------
// I/O lines definition.
// --------------------------------------------------------------------------
#define LCD_D4          RC0     // LCD display data bit 4
#define LCD_D5          RC1     // LCD display data bit 5
#define LCD_D6          RC2     // LCD display data bit 6
#define LCD_D7          RC3     // LCD display data bit 7
#define LCD_RS          RC4     // LCD display Register Select line (0=command, 1=data)
#define LCD_EN          RC5     // LCD display Enable line (1=enable)
#define LCD_LIGHT       RC6     // LCD backlight enable line (1=on)
#define LCD_DATA        PORTC   // LCD data port (use only RC0..3)

#define SW_UNITS        RB0     // Units swith (0=dB)
#define DP_0            RB4     // Decimal point bit 0
#define DP_1            RB5     // Decimal point bit 0
#define SCALE_0         RB6     // Scale bit 0
#define SCALE_1         RB7     // Scale bit 1

#define PWR_FWD         0       // AN0
#define PWR_REV         1       // AN1

#define LIGHT_ON        1
#define LIGHT_OFF       0



// --------------------------------------------------------------------------
// Exported procedures and functions (see io.c for description).
// --------------------------------------------------------------------------
void IO_init(void);



#endif


